@@ -19,6 +19,11 @@
 #' }
 echoSDWGetMeta <- function(verbose = FALSE){
 
+  ## check connectivity
+  if (!isTRUE(check_connectivity())) {
+    return(invisible(NULL))
+  }
+
   ## build the request URL statement
   path <- "echo/sdw_rest_services.metadata?output=JSON"
   getURL <- requestURL(path = path, query = NULL)
@@ -78,7 +83,7 @@ echoSDWGetSystems <- function(verbose = FALSE, ...) {
   ## check if qcolumns argument is provided by user
   ## if user does not provide qcolumns, provide a sensible default
   if (!("qcolumns" %in% names(valuesList))) {
-    qcolumns <- c(1:66)
+    qcolumns <- c(1:76)
     qcolumns <- paste(as.character(qcolumns), collapse = ",")
     valuesList[["qcolumns"]] <- qcolumns
   }
